﻿' *****************************************************************************
' NAntRunner
' A simple, standalone, utility for running NAnt build scripts.
'
' Developed by Mark Gilbert (http://www.mark-gilbert.com).
'
' This software is license under the Microsoft Public License (Ms-PL).  For full
' license details, please see 
' http://www.microsoft.com/resources/sharedsource/licensingbasics/publiclicense.mspx.
' *****************************************************************************

Imports System.IO
Imports System.Collections

Public Class NAntRunnerSettings

    Private _SettingsFileName As String
    Private _NAntExecutablePath As String
    Private _UtilitySize As Rectangle
    Private _Scripts As List(Of NAntScript)


#Region " Properties"
    Public Property NAntExecutablePath() As String
        Get
            If (IsNothing(Me._NAntExecutablePath)) Then Me._NAntExecutablePath = ""
            Return Me._NAntExecutablePath
        End Get
        Set(ByVal value As String)
            Me._NAntExecutablePath = value
        End Set
    End Property


    Public Property UtilitySize() As Rectangle
        Get
            If (IsNothing(Me._UtilitySize)) Then Me._UtilitySize = New Rectangle(0, 0, 672, 450)
            Return Me._UtilitySize
        End Get
        Set(ByVal value As Rectangle)
            Me._UtilitySize = value
        End Set
    End Property


    Public Property Scripts() As List(Of NAntScript)
        Get
            If (IsNothing(Me._Scripts)) Then Me._Scripts = New List(Of NAntScript)
            Return Me._Scripts
        End Get
        Set(ByVal value As List(Of NAntScript))
            Me._Scripts = value
        End Set
    End Property


    Public ReadOnly Property PathToSettingsFile() As String
        Get
            Dim ExecutionPath As String

            ExecutionPath = Path.GetDirectoryName(System.Reflection.Assembly.GetExecutingAssembly().Location)
            If (IsNothing(Me._SettingsFileName)) Then Me._SettingsFileName = "NAntRunnerSettings.xml"

            Return Path.Combine(ExecutionPath, Me._SettingsFileName)
        End Get
    End Property
#End Region


#Region " Constructors "
    Public Sub New(ByVal SettingsFileName As String)
        Me._SettingsFileName = SettingsFileName
        If (File.Exists(Me.PathToSettingsFile)) Then
            Me.LoadSettings(XDocument.Load(PathToSettingsFile))
        End If
    End Sub


    Public Sub New(ByVal SettingsFileName As String, ByVal SettingsFile As XDocument)
        Me._SettingsFileName = SettingsFileName
        Me.LoadSettings(SettingsFile)
    End Sub
#End Region


#Region " Methods "
    Private Sub LoadSettings(ByVal SettingsFile As XDocument)
        If (IsNothing(SettingsFile)) Then Return

        Me._NAntExecutablePath = SettingsFile...<NAntExecutable>.Value.ToString
        Me._UtilitySize = New Rectangle(0, 0, SettingsFile...<UtilitySize>.<Width>.Value, SettingsFile...<UtilitySize>.<Height>.Value)

        Me._Scripts = New List(Of NAntScript)
        Dim ScriptPaths = From s In SettingsFile...<Script> Select s
        For Each CurrentScriptPath In ScriptPaths
            Me._Scripts.Add(New NAntScript(CurrentScriptPath))
        Next
    End Sub


    Public Sub Save()
        Dim SettingsFile As XDocument

        SettingsFile = <?xml version="1.0" encoding="UTF-16" standalone="yes"?>
                       <NAntRunnerSettings>
                           <NAntExecutable>
                               <%= Me.NAntExecutablePath %>
                           </NAntExecutable>
                           <UtilitySize>
                               <Width><%= Me.UtilitySize.Width %></Width>
                               <Height><%= Me.UtilitySize.Height %></Height>
                           </UtilitySize>
                           <Scripts>
                               <%= From CurrentScript In Me.Scripts Select <Script>
                                                                               <ScriptPath><%= CurrentScript.ScriptPath %></ScriptPath>
                                                                           </Script> %>
                           </Scripts>
                       </NAntRunnerSettings>

        SettingsFile.Save(Me.PathToSettingsFile)
    End Sub
#End Region

End Class
