﻿' *****************************************************************************
' NAntRunner
' A simple, standalone, utility for running NAnt build scripts.
'
' Developed by Mark Gilbert (http://www.mark-gilbert.com).
'
' This software is license under the Microsoft Public License (Ms-PL).  For full
' license details, please see 
' http://www.microsoft.com/resources/sharedsource/licensingbasics/publiclicense.mspx.
' *****************************************************************************
Imports System.IO

Public Class NAntScript

    Private _ScriptPath As String
    Private _ScriptName As String


    Public Class InvalidScriptPathException
        Inherits System.Exception
    End Class


#Region " Constructors "
    Public Sub New(ByVal NewScriptPath As String)
        Me.New(NewScriptPath, Nothing)
    End Sub


    Public Sub New(ByVal NewScriptPath As String, ByVal NewScriptName As String)
        If (IsNothing(NewScriptPath)) Then Throw New InvalidScriptPathException
        NewScriptPath = NewScriptPath.Trim
        If (String.IsNullOrEmpty(NewScriptPath)) Then Throw New InvalidScriptPathException
        Me._ScriptPath = NewScriptPath

        If (IsNothing(NewScriptName)) Then NewScriptName = Path.GetFileName(NewScriptPath)
        Me._ScriptName = NewScriptName
    End Sub
#End Region


#Region " Properties "
    Public Property ScriptPath() As String
        Get
            If (IsNothing(Me._ScriptPath)) Then Me._ScriptPath = ""
            Return Me._ScriptPath
        End Get
        Set(ByVal value As String)
            Me._ScriptPath = ""
        End Set
    End Property


    Public Property ScriptName() As String
        Get
            If (IsNothing(Me._ScriptName)) Then Me._ScriptName = ""
            Return Me._ScriptName
        End Get
        Set(ByVal value As String)
            Me._ScriptName = value
        End Set
    End Property


    Public ReadOnly Property Value() As String
        Get
            Return Me._ScriptPath
        End Get
    End Property
#End Region


#Region " Methods "
    Public Overrides Function ToString() As String
        Return Me._ScriptName
    End Function
#End Region


End Class
