﻿' *****************************************************************************
' NAntRunner
' A simple, standalone, utility for running NAnt build scripts.
'
' Developed by Mark Gilbert (http://www.mark-gilbert.com).
'
' This software is license under the Microsoft Public License (Ms-PL).  For full
' license details, please see 
' http://www.microsoft.com/resources/sharedsource/licensingbasics/publiclicense.mspx.
' *****************************************************************************

''' <summary>
''' This encapsulates the logic for a single web site to be shown in a treeview.
''' </summary>
''' <remarks></remarks>
Public Class NavigationTreeNode
    Inherits TreeNode

    Private _DisplayName As String
    Private _Path As String


#Region " Custom Exceptions "
    Public Class InvalidDisplayNameException
        Inherits Exception

        Public Sub New()
            MyBase.New("Display Name cannot be empty.")
        End Sub
    End Class


    Public Class InvalidPathException
        Inherits Exception

        Public Sub New()
            MyBase.New("Path cannot be empty.")
        End Sub
    End Class
#End Region


#Region " Constructors "
    ''' <summary>
    ''' This constructor variant is needed when the object is cloned.
    ''' </summary>
    ''' <remarks></remarks>
    Public Sub New()
        MyBase.New("New Node")
    End Sub


    ''' <summary>
    ''' This variant creates a new Group node.
    ''' </summary>
    ''' <param name="NewDisplayName"></param>
    ''' <remarks></remarks>
    Public Sub New(ByVal NewDisplayName As String)
        MyBase.New(NewDisplayName)

        If (IsNothing(NewDisplayName)) Then NewDisplayName = ""
        If (NewDisplayName.Trim.Length = 0) Then Throw New InvalidDisplayNameException

        Me._DisplayName = NewDisplayName
    End Sub


    ''' <summary>
    ''' This variant creates a new Script node.
    ''' </summary>
    ''' <param name="NewDisplayName"></param>
    ''' <param name="NewPath"></param>
    ''' <remarks></remarks>
    Public Sub New(ByVal NewDisplayName As String, ByVal NewPath As String)
        MyBase.New(NewDisplayName)

        If (IsNothing(NewDisplayName)) Then NewDisplayName = ""
        If (NewDisplayName.Trim.Length = 0) Then Throw New InvalidDisplayNameException

        If (IsNothing(NewPath)) Then NewPath = ""
        If (NewPath.Trim.Length = 0) Then Throw New InvalidPathException

        Me._DisplayName = NewDisplayName
        Me._Path = NewPath
    End Sub
#End Region



#Region " Properties "
    Public Property DisplayName() As String
        Get
            If (IsNothing(Me._DisplayName)) Then Me._DisplayName = ""
            Return Me._DisplayName.Trim
        End Get
        Set(ByVal value As String)
            If (IsNothing(value)) Then value = ""
            If (value.Trim.Length = 0) Then Throw New InvalidDisplayNameException

            Me._DisplayName = value.Trim
        End Set
    End Property


    Public Property Path() As String
        Get
            If (IsNothing(Me._Path)) Then Me._Path = ""
            Return Me._Path.Trim
        End Get
        Set(ByVal value As String)
            If (IsNothing(value)) Then value = ""
            If (value.Trim.Length = 0) Then Throw New InvalidPathException

            Me._Path = value.Trim
        End Set
    End Property

    Public ReadOnly Property Value() As String
        Get
            Return Me.Path
        End Get
    End Property

#End Region


#Region " Methods "
    Public Overrides Function ToString() As String
        Return Me.DisplayName
    End Function
#End Region


End Class
