' *****************************************************************************
' NAntRunner
' A simple, standalone, utility for running NAnt build scripts.
'
' Developed by Mark Gilbert (http://www.mark-gilbert.com).
'
' This software is license under the Microsoft Public License (Ms-PL).  For full
' license details, please see 
' http://www.microsoft.com/resources/sharedsource/licensingbasics/publiclicense.mspx.
' *****************************************************************************
Imports NUnit.Framework
Imports NAntRunner
Imports System.Drawing
Imports NRBusinessServices

<TestFixture()> _
Public Class NAntRunnerSettingsTests

    Private _MySettings As NAntRunnerSettings
    Private _MyTestEXE As String
    Private _MyTestWidth As Integer
    Private _MyTestHeight As Integer

#Region " Properties "
    Private ReadOnly Property TestSettingsFile_v0_2() As XDocument
        Get
            Return <?xml version="1.0" encoding="UTF-16" standalone="yes"?>
                   <NAntRunnerSettings>
                       <NAntExecutable>
                           <%= Me._MyTestEXE %>
                       </NAntExecutable>
                       <UtilitySize>
                           <Width><%= Me._MyTestWidth %></Width>
                           <Height><%= Me._MyTestHeight %></Height>
                       </UtilitySize>
                       <Scripts>
                           <Script>
                               <ScriptPath>C:\SomePath\Script1.build</ScriptPath>
                           </Script>
                           <Script>
                               <ScriptPath>C:\SomePath2\Script2.build</ScriptPath>
                           </Script>
                           <Script>
                               <ScriptPath>C:\SomePath3\Script3.build</ScriptPath>
                           </Script>
                       </Scripts>
                   </NAntRunnerSettings>
        End Get
    End Property

    Private ReadOnly Property TestSettingsFile_v0_3() As XDocument
        Get
            Return <?xml version="1.0" encoding="UTF-16" standalone="yes"?>
                   <NAntRunnerSettings>
                       <SettingsFileVersion>0.3</SettingsFileVersion>
                       <NAntExecutable>
                           <%= Me._MyTestEXE %>
                       </NAntExecutable>
                       <UtilitySize>
                           <Width><%= Me._MyTestWidth %></Width>
                           <Height><%= Me._MyTestHeight %></Height>
                       </UtilitySize>
                       <ScriptGroups>
                           <ScriptGroup Name="Default">
                               <Script>
                                   <ScriptPath>C:\SomePath\Script1.build</ScriptPath>
                                   <ScriptName>Script1.build</ScriptName>
                               </Script>
                               <Script>
                                   <ScriptPath>C:\SomePath2\Script2.build</ScriptPath>
                                   <ScriptName>Script2.build</ScriptName>
                               </Script>
                               <Script>
                                   <ScriptPath>C:\SomePath3\Script3.build</ScriptPath>
                                   <ScriptName>Script3.build</ScriptName>
                               </Script>
                           </ScriptGroup>
                       </ScriptGroups>
                   </NAntRunnerSettings>
        End Get
    End Property
#End Region


#Region " Setup/Teardown "
    <SetUp()> _
    Public Sub SetUp()
        Me._MyTestEXE = "C:\Program Files\NAnt\NAnt.exe"
        Me._MyTestWidth = 700
        Me._MyTestHeight = 600
    End Sub
#End Region


    <Test()> _
    Public Sub Instantiate_ObjectNotNothing()
        Me._MySettings = New NAntRunnerSettings()

        Assert.IsFalse(IsNothing(Me._MySettings))
    End Sub

    <Test()> _
    Public Sub InstantiateWithMissingFile_CreatesBlankSettingsObject()
        Me._MySettings = New NAntRunnerSettings()

        Assert.AreEqual(NAntRunnerSettings.CURRENT_NANTRUNNER_SETTINGS_FILE_VERSION, Me._MySettings.SettingsFileVersion)
        Assert.IsFalse(IsNothing(Me._MySettings.NAntExecutablePath))
        Assert.IsFalse(IsNothing(Me._MySettings.UtilitySize))
        Assert.IsFalse(IsNothing(Me._MySettings.ScriptGroups))
    End Sub

    <Test()> _
    Public Sub InstantiateWithValidSettingsFile_NAntExecutableIsCorrect()
        Me._MySettings = New NAntRunnerSettings(Me.TestSettingsFile_v0_2)
        Assert.AreEqual("C:\Program Files\NAnt\NAnt.exe", Me._MySettings.NAntExecutablePath)
    End Sub

    <Test()> _
    Public Sub InstantiateWithValidSettingsFile_UtilitySizeIsCorrect()
        Me._MySettings = New NAntRunnerSettings(Me.TestSettingsFile_v0_2)
        Assert.IsTrue(New Rectangle(0, 0, Me._MyTestWidth, Me._MyTestHeight).Equals(Me._MySettings.UtilitySize))
    End Sub

    <Test()> _
    Public Sub InstantiateWithValidSettingsFile_ScriptGroupCollectionIsCorrect()
        Me._MySettings = New NAntRunnerSettings(Me.TestSettingsFile_v0_2)
        Assert.AreEqual(1, Me._MySettings.ScriptGroups.Count)
    End Sub

    <Test()> _
    Public Sub InstantiateWithValidSettingsFile_ScriptCollectionIsCorrect()
        Me._MySettings = New NAntRunnerSettings(Me.TestSettingsFile_v0_2)
        Assert.AreEqual(3, Me._MySettings.ScriptGroups.Item(0).Scripts.Count)
    End Sub

    <Test()> _
    Public Sub Version_0_2_FileRead_UpgradedSuccessfully()
        Dim ConvertedDoc As XDocument
        Dim VersionToUpgradeTo As Single = 0.3

        Me._MySettings = New NAntRunnerSettings(Me.TestSettingsFile_v0_2)
        ConvertedDoc = Me._MySettings.Save()

        Trace.WriteLine("Verifying that the settings file can be upgraded to version " & VersionToUpgradeTo.ToString)
        Assert.AreEqual(VersionToUpgradeTo, CType(ConvertedDoc...<NAntRunnerSettings>.<SettingsFileVersion>.Value, Single))
        Assert.AreEqual("C:\Program Files\NAnt\NAnt.exe", ConvertedDoc...<NAntRunnerSettings>.<NAntExecutable>.Value)
        Assert.AreEqual(Me._MyTestWidth, CType(ConvertedDoc...<NAntRunnerSettings>.<UtilitySize>.<Width>.Value, Integer))
        Assert.AreEqual(Me._MyTestHeight, CType(ConvertedDoc...<NAntRunnerSettings>.<UtilitySize>.<Height>.Value, Integer))
        Assert.AreEqual(3, ConvertedDoc...<NAntRunnerSettings>.<ScriptGroups>.<ScriptGroup>.<Script>.Count)
        Assert.AreEqual("Default", ConvertedDoc...<NAntRunnerSettings>.<ScriptGroups>.<ScriptGroup>.@Name)
        Assert.IsTrue(ConvertedDoc...<NAntRunnerSettings>.<ScriptGroups>.<ScriptGroup>.<Script>.<ScriptPath>.Value.Length > 0)
        Assert.IsTrue(ConvertedDoc...<NAntRunnerSettings>.<ScriptGroups>.<ScriptGroup>.<Script>.<ScriptName>.Value.Length > 0)
    End Sub



End Class
