﻿' *****************************************************************************
' NAntRunner
' A simple, standalone, utility for running NAnt build scripts.
'
' Developed by Mark Gilbert (http://www.mark-gilbert.com).
'
' This software is license under the Microsoft Public License (Ms-PL).  For full
' license details, please see 
' http://www.microsoft.com/resources/sharedsource/licensingbasics/publiclicense.mspx.
' *****************************************************************************
Imports NUnit.Framework
Imports NAntRunner
Imports System.IO
Imports NRBusinessServices

<TestFixture()> _
Public Class NAntScriptTests

    Private Const TEST_SCRIPT_PATH As String = "C:\MyScriptPath\Script.build"
    Private Const TEST_SCRIPT_NAME As String = "My Script"
    Private Const TEST_SCRIPT_GROUP As String = "New Group A"
    Private Const DEFAULT_SCRIPT_GROUP As String = "Default"

    Private _MyNAntScriptShort As NAntScript
    Private _MyNAntScriptLong As NAntScript


#Region " Setup/TearDown "
    <SetUp()> _
    Public Sub Setup()
        Me._MyNAntScriptShort = New NAntScript(TEST_SCRIPT_PATH)
        Me._MyNAntScriptLong = New NAntScript(TEST_SCRIPT_PATH, TEST_SCRIPT_NAME)
    End Sub
#End Region


    <Test()> _
    Public Sub InstantiateClassWithOnlyPath_PathIsSetCorrectly()
        Assert.AreEqual(TEST_SCRIPT_PATH, Me._MyNAntScriptShort.ScriptPath)
    End Sub

    <Test()> _
    Public Sub InstantiateClassWithOnlyPath_NameIsSetCorrectly()
        Assert.AreEqual(Path.GetFileName(TEST_SCRIPT_PATH), Me._MyNAntScriptShort.ScriptName)
    End Sub

    <Test()> _
    Public Sub InstantiateClassUsingFullConstructor_PathIsSetCorrectly()
        Assert.AreEqual(TEST_SCRIPT_PATH, Me._MyNAntScriptLong.ScriptPath)
    End Sub

    <Test()> _
    Public Sub InstantiateClassUsingFullConstructor_NameIsSetCorrectly()
        Assert.AreEqual(TEST_SCRIPT_NAME, Me._MyNAntScriptLong.ScriptName)
    End Sub

    <Test()> _
    Public Sub InstantiateClassUsingFullConstructorAndNothings_GroupIsSetCorrectly()
        Dim MyNAntScript As NAntScript
        MyNAntScript = New NAntScript(TEST_SCRIPT_PATH, Nothing)

        Assert.AreEqual(TEST_SCRIPT_PATH, MyNAntScript.ScriptPath)
        Assert.AreEqual(Path.GetFileName(TEST_SCRIPT_PATH), MyNAntScript.ScriptName)
    End Sub

    <Test()> _
    Public Sub InstantiateClass_ScriptPathOfNothing_ExceptionThrown()
        Dim MyNAntScript As NAntScript
        Dim WasCorrectExceptionThrown As Boolean
        Dim ExceptionText As String

        WasCorrectExceptionThrown = False
        ExceptionText = "{exception text not set}"

        Try
            MyNAntScript = New NAntScript(Nothing, Nothing)
        Catch ex As NAntScript.InvalidScriptPathException
            WasCorrectExceptionThrown = True
            ExceptionText = ""
        Catch ex As Exception
            WasCorrectExceptionThrown = False
            ExceptionText = ex.Message
        End Try

        Assert.IsTrue(WasCorrectExceptionThrown, "Expected exception was not thrown; this one was: '" & ExceptionText & "'")
    End Sub

    <Test()> _
    Public Sub InstantiateClass_ScriptPathEmpty_ExceptionThrown()
        Dim MyNAntScript As NAntScript
        Dim WasCorrectExceptionThrown As Boolean
        Dim ExceptionText As String

        WasCorrectExceptionThrown = False
        ExceptionText = "{exception text not set}"

        Try
            MyNAntScript = New NAntScript("", Nothing)
        Catch ex As NAntScript.InvalidScriptPathException
            WasCorrectExceptionThrown = True
            ExceptionText = ""
        Catch ex As Exception
            WasCorrectExceptionThrown = False
            ExceptionText = ex.Message
        End Try

        Assert.IsTrue(WasCorrectExceptionThrown, "Expected exception was not thrown; this one was: '" & ExceptionText & "'")
    End Sub

    <Test()> _
    Public Sub InstantiateClass_ScriptPathBlank_ExceptionThrown()
        Dim MyNAntScript As NAntScript
        Dim WasCorrectExceptionThrown As Boolean
        Dim ExceptionText As String

        WasCorrectExceptionThrown = False
        ExceptionText = "{exception text not set}"

        Try
            MyNAntScript = New NAntScript("  ", Nothing)
        Catch ex As NAntScript.InvalidScriptPathException
            WasCorrectExceptionThrown = True
            ExceptionText = ""
        Catch ex As Exception
            WasCorrectExceptionThrown = False
            ExceptionText = ex.Message
        End Try

        Assert.IsTrue(WasCorrectExceptionThrown, "Expected exception was not thrown; this one was: '" & ExceptionText & "'")
    End Sub
End Class
